@@ -24,8 +24,8 @@
 
 /**
  * \file LALInferenceMCMCSampler.h
+ * \ingroup lalapps_inspiral
  * \brief Markov-Chain Monte Carlo sampler written for LALInference. Independent of model.
- * \ingroup LALInference
  *
  * Markov-Chain Monte Carlo sampler incorporating parallel tempering using MPI and
  * the possibility of adaptative jumps.
@@ -73,6 +73,7 @@ void acknowledgePhase(LALInferenceRunState *runState);
 void LALInferenceAdaptation(LALInferenceRunState *runState, INT4 cycle);
 void LALInferenceAdaptationRestart(LALInferenceRunState *runState, INT4 cycle);
 void LALInferenceAdaptationEnvelope(LALInferenceRunState *runState, INT4 cycle);
+void LALInferenceShutdownLadder(void);
 void LALInferenceFlushPTswap(void);
 void LALInferenceLadderUpdate(LALInferenceRunState *runState, INT4 sourceChainFlag, INT4 cycle);
 
