@@ -66,7 +66,7 @@ if __name__=='__main__':
   logLcol=headers.index('logl')
 
   if opts.npos is not None:
-     sampler=lambda datas,Nlives,logLcol,**kwargs: draw_N_posterior_many(datas,Nlives,opts.npos,logLcol=logLcol,**kwargs)
+     sampler=lambda datas,Nlives,logLcols,**kwargs: draw_N_posterior_many(datas,Nlives,opts.npos,logLcols=logLcols,**kwargs)
   else:
      sampler=draw_posterior_many
 
@@ -80,7 +80,7 @@ if __name__=='__main__':
 
   # Create posterior samples for each input file
   inarrays=map(loadtxt,datafiles)
-  posterior=sampler(inarrays,[int(opts.Nlive) for d in datafiles],logLcol=logLcol,verbose=opts.verbose)
+  posterior=sampler(inarrays,[int(opts.Nlive) for d in datafiles],logLcols=[logLcol for d in datafiles],verbose=opts.verbose)
   log_evs,log_wts=zip(*[compute_weights(data[:,logLcol],opts.Nlive) for data in inarrays])
   if opts.verbose:
     print 'Log evidences from input files: %s'%(str(log_evs))
