@@ -31,8 +31,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <getopt.h>
-#include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -45,6 +43,7 @@
 #include <processtable.h>
 
 #include <lal/LALConfig.h>
+#include <lal/LALgetopt.h>
 #include <lal/LALStdio.h>
 #include <lal/LALStdlib.h>
 #include <lal/LALError.h>
@@ -724,8 +723,8 @@ this_proc_param = this_proc_param->next = (ProcessParamsTable *) \
 
 int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
 {
-  /* getopt arguments */
-  struct option long_options[] =
+  /* LALgetopt arguments */
+  struct LALoption long_options[] =
   {
     /* these options set a flag */
     {"verbose",                 no_argument,       &vrbflg,           1 },
@@ -762,11 +761,11 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
 
   while ( 1 )
   {
-    /* getopt_long stores long option here */
+    /* LALgetopt_long stores long option here */
     int option_index = 0;
-    size_t optarg_len;
+    size_t LALoptarg_len;
 
-    c = getopt_long_only( argc, argv, "ha:b:c:e:m:s:A:B:C:N:P:S:Z:",
+    c = LALgetopt_long_only( argc, argv, "ha:b:c:e:m:s:A:B:C:N:P:S:Z:",
         long_options, &option_index );
 
     /* detect the end of the options */
@@ -786,7 +785,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         else
         {
           fprintf( stderr, "error parsing option %s with argument %s\n",
-              long_options[option_index].name, optarg );
+              long_options[option_index].name, LALoptarg );
           exit( 1 );
         }
         break;
@@ -798,9 +797,9 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
 
       case 'Z':
         /* create storage for the usertag */
-        optarg_len = strlen( optarg ) + 1;
-        userTag = (CHAR *) calloc( optarg_len, sizeof(CHAR) );
-        memcpy( userTag, optarg, optarg_len );
+        LALoptarg_len = strlen( LALoptarg ) + 1;
+        userTag = (CHAR *) calloc( LALoptarg_len, sizeof(CHAR) );
+        memcpy( userTag, LALoptarg, LALoptarg_len );
 
         this_proc_param = this_proc_param->next = (ProcessParamsTable *)
           calloc( 1, sizeof(ProcessParamsTable) );
@@ -809,19 +808,19 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         snprintf( this_proc_param->param, LIGOMETA_PARAM_MAX, "--userTag" );
         snprintf( this_proc_param->type, LIGOMETA_TYPE_MAX, "string" );
         snprintf( this_proc_param->value, LIGOMETA_VALUE_MAX, "%s",
-            optarg );
+            LALoptarg );
         break;
 
       case 'P':
         /* create storage for the psd file name */
-        optarg_len = strlen( optarg ) + 1;
-        psdFileName = (CHAR *) calloc( optarg_len, sizeof(CHAR) );
-        memcpy( psdFileName, optarg, optarg_len );
+        LALoptarg_len = strlen( LALoptarg ) + 1;
+        psdFileName = (CHAR *) calloc( LALoptarg_len, sizeof(CHAR) );
+        memcpy( psdFileName, LALoptarg, LALoptarg_len );
         ADD_PROCESS_PARAM( "string", "%s", psdFileName );
         break;
 
       case 'a':
-        minMass = (REAL4) atof( optarg );
+        minMass = (REAL4) atof( LALoptarg );
         if ( minMass <= 0 )
         {
           fprintf( stdout, "invalid argument to --%s:\n"
@@ -834,7 +833,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'A':
-        maxMass = (REAL4) atof( optarg );
+        maxMass = (REAL4) atof( LALoptarg );
         if ( maxMass <= 0 )
         {
           fprintf( stdout, "invalid argument to --%s:\n"
@@ -847,7 +846,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'b':
-        minMTotal = (REAL4) atof( optarg );
+        minMTotal = (REAL4) atof( LALoptarg );
         if ( minMTotal <= 0 )
         {
           fprintf( stdout, "invalid argument to --%s:\n"
@@ -860,7 +859,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'B':
-        maxMTotal = (REAL4) atof( optarg );
+        maxMTotal = (REAL4) atof( LALoptarg );
         if ( maxMTotal <= 0 )
         {
           fprintf( stdout, "invalid argument to --%s:\n"
@@ -873,7 +872,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'c':
-        minMChirp = (REAL4) atof( optarg );
+        minMChirp = (REAL4) atof( LALoptarg );
         if ( minMChirp <= 0 )
         {
           fprintf( stdout, "invalid argument to --%s:\n"
@@ -886,7 +885,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'C':
-        maxMChirp = (REAL4) atof( optarg );
+        maxMChirp = (REAL4) atof( LALoptarg );
         if ( maxMChirp <= 0 )
         {
           fprintf( stdout, "invalid argument to --%s:\n"
@@ -899,7 +898,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'f':
-        fLo = (REAL4) atof( optarg );
+        fLo = (REAL4) atof( LALoptarg );
         if ( fLo <= 0 )
         {
           fprintf( stdout, "invalid argument to --%s:\n"
@@ -912,7 +911,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'F':
-        fHi = (REAL4) atof( optarg );
+        fHi = (REAL4) atof( LALoptarg );
         if ( fHi <= 0 )
         {
           fprintf( stdout, "invalid argument to --%s:\n"
@@ -925,21 +924,21 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'J':
-        if ( ! strcmp( "urandom", optarg ) )
+        if ( ! strcmp( "urandom", LALoptarg ) )
         {
           randSeedType = urandom;
-          ADD_PROCESS_PARAM( "string", "%s", optarg );
+          ADD_PROCESS_PARAM( "string", "%s", LALoptarg );
         }
         else
         {
           randSeedType = user;
-          randomSeed = (INT4) atoi( optarg );
+          randomSeed = (INT4) atoi( LALoptarg );
           ADD_PROCESS_PARAM( "int", "%d", randomSeed );
         }
         break;
 
       case 'N':
-        facTries = (INT4) atoi( optarg );
+        facTries = (INT4) atoi( LALoptarg );
         if ( facTries < 1 )
         {
           fprintf( stderr, "invalid argument to --%s:\n"
@@ -952,7 +951,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
         break;
 
       case 'm':
-        minMatch = (REAL4) atof( optarg );
+        minMatch = (REAL4) atof( LALoptarg );
         if ( minMatch < 0 || minMatch >= 1 )
         {
           fprintf( stderr, "invalid argument to --%s:\n"
@@ -966,7 +965,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
 
       case 's':
         {
-          long int gstartt = atol( optarg );
+          long int gstartt = atol( LALoptarg );
           if ( gstartt < 441417609 )
           {
             fprintf( stderr, "invalid argument to --%s:\n"
@@ -993,7 +992,7 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
 
       case 'e':
         {
-          long int gendt = atol( optarg );
+          long int gendt = atol( LALoptarg );
           if ( gendt > 999999999 )
           {
             fprintf( stderr, "invalid argument to --%s:\n"
@@ -1030,12 +1029,12 @@ int arg_parse_check( int argc, char *argv[], MetadataTable procparams )
     }
   }
 
-  if ( optind < argc )
+  if ( LALoptind < argc )
   {
     fprintf( stderr, "extraneous command line arguments:\n" );
-    while ( optind < argc )
+    while ( LALoptind < argc )
     {
-      fprintf ( stderr, "%s\n", argv[optind++] );
+      fprintf ( stderr, "%s\n", argv[LALoptind++] );
     }
     exit( 1 );
   }
