@@ -17,11 +17,13 @@
 *  MA  02111-1307  USA
 */
 
+#define _GNU_SOURCE     /* for setenv() and putenv() */
+
+#include <stdlib.h>
 #include <ctype.h>
 #include <errno.h>
 #include <math.h>
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 
@@ -32,6 +34,8 @@
 #include "getdate.h"
 #include "lalapps.h"
 
+#include "config.h"
+
 #ifdef __GNUC__
 #define UNUSED __attribute__ ((unused))
 #else
