@@ -29,7 +29,6 @@
  */
 
 
-#include <getopt.h>
 #include <lalapps.h>
 #include <math.h>
 #include <processtable.h>
@@ -42,6 +41,7 @@
 #include <gsl/gsl_randist.h>
 
 #include <lal/AVFactories.h>
+#include <lal/LALgetopt.h>
 #include <lal/BandPassTimeSeries.h>
 #include <lal/Date.h>
 #include <lal/EPSearch.h>
@@ -67,13 +67,12 @@
 #include <lal/LIGOLwXMLBurstRead.h>
 #include <lal/LIGOLwXMLInspiralRead.h>
 #include <lal/LIGOMetadataTables.h>
-#include <lal/LIGOMetadataBurstUtils.h>
 #include <lal/Random.h>
 #include <lal/RealFFT.h>
 #include <lal/ResampleTimeSeries.h>
 #include <lal/SeqFactories.h>
 #include <lal/SimulateCoherentGW.h>
-#include <lal/TFTransform.h>
+#include <lal/SnglBurstUtils.h>
 #include <lal/TimeFreqFFT.h>
 #include <lal/TimeSeries.h>
 #include <lal/Units.h>
@@ -242,8 +241,7 @@ struct options {
 	 * diagnostics support
 	 */
 
-	/* diagnostics call back for passing to LAL (NULL = disable) */
-	struct XLALEPSearchDiagnostics *diagnostics;
+	LIGOLwXMLStream *diagnostics;
 };
 
 
@@ -358,7 +356,7 @@ static void print_missing_argument(const char *prog, const char *arg)
  */
 
 
-static int all_required_arguments_present(char *prog, struct option *long_options, const struct options *options)
+static int all_required_arguments_present(char *prog, struct LALoption *long_options, const struct options *options)
 {
 	int option_index;
 	int got_all_arguments = 1;
@@ -459,7 +457,7 @@ static ProcessParamsTable **add_process_param(ProcessParamsTable **proc_param, c
 
 
 #define ADD_PROCESS_PARAM(process, type) \
-	do { paramaddpoint = add_process_param(paramaddpoint, process, type, long_options[option_index].name, optarg); } while(0)
+	do { paramaddpoint = add_process_param(paramaddpoint, process, type, long_options[option_index].name, LALoptarg); } while(0)
 
 
 /*
@@ -474,7 +472,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 	int args_are_bad = 0;
 	int c;
 	int option_index;
-	struct option long_options[] = {
+	struct LALoption long_options[] = {
 		{"bandwidth", required_argument, NULL, 'A'},
 		{"injection-file", required_argument, NULL, 'P'},
 		{"calibration-cache", required_argument, NULL, 'B'},
@@ -517,11 +515,11 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 	 * Parse command line.
 	 */
 
-	opterr = 1;		/* enable error messages */
-	optind = 0;		/* start scanning from argv[0] */
-	do switch (c = getopt_long(argc, argv, "", long_options, &option_index)) {
+	LALopterr = 1;		/* enable error messages */
+	LALoptind = 0;		/* start scanning from argv[0] */
+	do switch (c = LALgetopt_long(argc, argv, "", long_options, &option_index)) {
 	case 'A':
-		options->bandwidth = atof(optarg);
+		options->bandwidth = atof(LALoptarg);
 		if(options->bandwidth <= 0 || !double_is_power_of_2(options->bandwidth)) {
 			sprintf(msg, "must be greater than 0 and a power of 2 (%g specified)", options->bandwidth);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -531,18 +529,18 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'B':
-		options->cal_cache_filename = optarg;
+		options->cal_cache_filename = LALoptarg;
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
 	case 'C':
-		options->channel_name = optarg;
-		memcpy(options->ifo, optarg, sizeof(options->ifo) - 1);
+		options->channel_name = LALoptarg;
+		memcpy(options->ifo, LALoptarg, sizeof(options->ifo) - 1);
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
 	case 'F':
-		options->max_event_rate = atoi(optarg);
+		options->max_event_rate = atoi(LALoptarg);
 		if(options->max_event_rate < 0) {
 			sprintf(msg, "must not be negative (%d specified)", options->max_event_rate);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -552,13 +550,13 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'G':
-		options->cache_filename = optarg;
+		options->cache_filename = LALoptarg;
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
 	case 'K':
-		if(XLALStrToGPS(&options->gps_end, optarg, NULL)) {
-			sprintf(msg, "range error parsing \"%s\"", optarg);
+		if(XLALStrToGPS(&options->gps_end, LALoptarg, NULL)) {
+			sprintf(msg, "range error parsing \"%s\"", LALoptarg);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
 			args_are_bad = 1;
 		}
@@ -566,8 +564,8 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'M':
-		if(XLALStrToGPS(&options->gps_start, optarg, NULL)) {
-			sprintf(msg, "range error parsing \"%s\"", optarg);
+		if(XLALStrToGPS(&options->gps_start, LALoptarg, NULL)) {
+			sprintf(msg, "range error parsing \"%s\"", LALoptarg);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
 			args_are_bad = 1;
 		}
@@ -580,12 +578,12 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'P':
-		options->injection_filename = optarg;
+		options->injection_filename = LALoptarg;
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
 	case 'Q':
-		options->flow = atof(optarg);
+		options->flow = atof(LALoptarg);
 		if(options->flow < 0) {
 			sprintf(msg, "must not be negative (%f Hz specified)", options->flow);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -595,17 +593,17 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'R':
-		options->mdc_cache_filename = optarg;
+		options->mdc_cache_filename = LALoptarg;
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
 	case 'S':
-		options->mdc_channel_name = optarg;
+		options->mdc_channel_name = LALoptarg;
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
 	case 'V':
-		options->noise_rms = atof(optarg);
+		options->noise_rms = atof(LALoptarg);
 		if(options->noise_rms <= 0.0) {
 			sprintf(msg, "must be greater than 0 (%f specified)", options->noise_rms);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -616,7 +614,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 
 	case 'W':
 		{
-		int window_length = atoi(optarg);
+		int window_length = atoi(LALoptarg);
 		if((window_length < 4) || !is_power_of_2(window_length)) {
 			sprintf(msg, "must be greater than or equal to 4 and a power of 2 (%i specified)", window_length);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -636,11 +634,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 
 	case 'X':
 #if 0
-		options->diagnostics = malloc(sizeof(*options->diagnostics));
-		options->diagnostics->LIGOLwXMLStream = XLALOpenLIGOLwXMLFile(optarg);
-		options->diagnostics->XLALWriteLIGOLwXMLArrayREAL8FrequencySeries = XLALWriteLIGOLwXMLArrayREAL8FrequencySeries;
-		options->diagnostics->XLALWriteLIGOLwXMLArrayREAL8TimeSeries = XLALWriteLIGOLwXMLArrayREAL8TimeSeries;
-		options->diagnostics->XLALWriteLIGOLwXMLArrayCOMPLEX16FrequencySeries = XLALWriteLIGOLwXMLArrayCOMPLEX16FrequencySeries;
+		options->diagnostics = XLALOpenLIGOLwXMLFile(LALoptarg);
 #else
 		sprintf(msg, "--dump-diagnostics given but diagnostic code not included at compile time");
 		args_are_bad = 1;
@@ -648,7 +642,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'Z':
-		options->psd_length = atoi(optarg);
+		options->psd_length = atoi(LALoptarg);
 		ADD_PROCESS_PARAM(process, "int");
 		break;
 
@@ -658,9 +652,9 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		 * guestimated limit on the length of a time series to read
 		 * in.
 		 */
-		options->max_series_length = atoi(optarg) * 1024 * 1024 / (8 * sizeof(REAL8));
+		options->max_series_length = atoi(LALoptarg) * 1024 * 1024 / (8 * sizeof(REAL8));
 		if(options->max_series_length <= 0) {
-			sprintf(msg, "must be greater than 0 (%i specified)", atoi(optarg));
+			sprintf(msg, "must be greater than 0 (%i specified)", atoi(LALoptarg));
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
 			args_are_bad = 1;
 		}
@@ -668,17 +662,17 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'b':
-		options->output_filename = optarg;
+		options->output_filename = LALoptarg;
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
 	case 'c':
-		options->seed = atol(optarg);
+		options->seed = atol(LALoptarg);
 		ADD_PROCESS_PARAM(process, "long");
 		break;
 
 	case 'e':
-		options->resample_rate = atoi(optarg);
+		options->resample_rate = atoi(LALoptarg);
 		if(options->resample_rate < 2 || options->resample_rate > 16384 || !is_power_of_2(options->resample_rate)) {
 			sprintf(msg, "must be a power of 2 in the rage [2,16384] (%d specified)", options->resample_rate);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -688,7 +682,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'f':
-		options->fractional_stride = atof(optarg);
+		options->fractional_stride = atof(LALoptarg);
 		if(options->fractional_stride > 1 || !double_is_power_of_2(options->fractional_stride)) {
 			sprintf(msg, "must be less than or equal to 1 and a power of 2 (%g specified)", options->fractional_stride);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -698,7 +692,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'g':
-		options->confidence_threshold = atof(optarg);
+		options->confidence_threshold = atof(LALoptarg);
 		if(options->confidence_threshold < 0) {
 			sprintf(msg, "must not be negative (%g specified)", options->confidence_threshold);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -708,12 +702,12 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'h':
-		options->comment = optarg;
+		options->comment = LALoptarg;
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
 	case 'j':
-		options->filter_corruption = atoi(optarg);
+		options->filter_corruption = atoi(LALoptarg);
 		if(options->filter_corruption < 0) {
 			sprintf(msg, "must not be negative (%d specified)", options->filter_corruption);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -723,7 +717,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'l':
-		options->maxTileBandwidth = atof(optarg);
+		options->maxTileBandwidth = atof(LALoptarg);
 		if((options->maxTileBandwidth <= 0) || !double_is_power_of_2(options->maxTileBandwidth)) {
 			sprintf(msg, "must be greater than 0 and a power of 2 (%f specified)", options->maxTileBandwidth);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -733,7 +727,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'm':
-		options->maxTileDuration = atof(optarg);
+		options->maxTileDuration = atof(LALoptarg);
 		if((options->maxTileDuration <= 0) || !double_is_power_of_2(options->maxTileDuration)) {
 			sprintf(msg, "must be greater than 0 and a power of 2 (%f specified)", options->maxTileDuration);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -743,7 +737,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 		break;
 
 	case 'o':
-		options->high_pass = atof(optarg);
+		options->high_pass = atof(LALoptarg);
 		if(options->high_pass < 0) {
 			sprintf(msg, "must not be negative (%f Hz specified)", options->high_pass);
 			print_bad_argument(argv[0], long_options[option_index].name, msg);
@@ -754,7 +748,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 
 	/* option sets a flag */
 	case 0:
-		optarg = NULL;
+		LALoptarg = NULL;
 		ADD_PROCESS_PARAM(process, "string");
 		break;
 
@@ -808,10 +802,13 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 	 * Compute timing parameters.
 	 */
 
-	if(XLALEPGetTimingParameters(options->window->data->length, options->maxTileDuration * options->resample_rate, options->fractional_stride, &options->psd_length, &options->psd_shift, &options->window_shift, &options->window_pad, NULL) < 0) {
+	{
+	int tiling_length;	/* unused */
+	if(XLALEPGetTimingParameters(options->window->data->length, options->maxTileDuration * options->resample_rate, options->fractional_stride, &options->psd_length, &options->psd_shift, &options->window_shift, &options->window_pad, &tiling_length) < 0) {
 		XLALPrintError("calculation of timing parameters failed\n");
 		exit(1);
 	}
+	}
 
 	/*
 	 * Ensure RAM limit is comensurate with the psd_length and its
@@ -857,7 +854,7 @@ static struct options *parse_command_line(int argc, char *argv[], const ProcessT
 	 * Miscellaneous chores.
 	 */
 
-	XLALPrintInfo("%s: using --psd-average-points %zu\n", argv[0], options->psd_length);
+	XLALPrintInfo("%s: using --psd-average-points %i\n", argv[0], options->psd_length);
 	if(options->max_series_length)
 		XLALPrintInfo("%s: available RAM limits analysis to %d samples (%g s)\n", argv[0], options->max_series_length, options->max_series_length / (double) options->resample_rate);
 
@@ -1146,24 +1143,14 @@ static void destroy_injection_document(struct injection_document *doc)
 }
 
 
-static struct injection_document *load_injection_document(const char *filename, LIGOTimeGPS start, LIGOTimeGPS end)
+static struct injection_document *load_injection_document(const char *filename)
 {
 	struct injection_document *new;
-	/* hard-coded speed hack.  only injections whose "times" are within
-	 * this many seconds of the requested interval will be loaded */
-	const double longest_injection = 600.0;
 
 	new = malloc(sizeof(*new));
 	if(!new)
 		XLAL_ERROR_NULL(XLAL_ENOMEM);
 
-	/*
-	 * adjust start and end times
-	 */
-
-	XLALGPSAdd(&start, -longest_injection);
-	XLALGPSAdd(&end, longest_injection);
-
 	/*
 	 * load required tables
 	 */
@@ -1179,7 +1166,7 @@ static struct injection_document *load_injection_document(const char *filename,
 
 	new->has_sim_burst_table = XLALLIGOLwHasTable(filename, "sim_burst");
 	if(new->has_sim_burst_table) {
-		new->sim_burst_table_head = XLALSimBurstTableFromLIGOLw(filename, &start, &end);
+		new->sim_burst_table_head = XLALSimBurstTableFromLIGOLw(filename, NULL, NULL);
 	} else
 		new->sim_burst_table_head = NULL;
 
@@ -1189,7 +1176,9 @@ static struct injection_document *load_injection_document(const char *filename,
 
 	new->has_sim_inspiral_table = XLALLIGOLwHasTable(filename, "sim_inspiral");
 	if(new->has_sim_inspiral_table) {
-		if(SimInspiralTableFromLIGOLw(&new->sim_inspiral_table_head, filename, start.gpsSeconds - 1, end.gpsSeconds + 1) < 0)
+		/* FIXME:  find way to ask for "everything" (see
+		 * XLALSimBurstTableFromLIGOLw for example) */
+		if(SimInspiralTableFromLIGOLw(&new->sim_inspiral_table_head, filename, 0, 2147483647) < 0)
 			new->sim_inspiral_table_head = NULL;
 	} else
 		new->sim_inspiral_table_head = NULL;
@@ -1339,7 +1328,7 @@ static SnglBurst **analyze_series(SnglBurst **addpoint, REAL8TimeSeries *series,
 		XLALPrintInfo("%s(): ", __func__);
 		XLALPrintProgressBar(i / (double) (series->data->length + psd_shift - psd_length));
 		XLALPrintInfo(" complete\n");
-		XLALPrintInfo("%s(): analyzing samples %zu -- %zu (%.9lf s -- %.9lf s)\n", __func__, start, start + interval->data->length, start * interval->deltaT, (start + interval->data->length) * interval->deltaT);
+		XLALPrintInfo("%s(): analyzing samples %i -- %i (%.9lf s -- %.9lf s)\n", __func__, start, start + interval->data->length, start * interval->deltaT, (start + interval->data->length) * interval->deltaT);
 
 		XLAL_TRY(*addpoint = XLALEPSearch(
 			options->diagnostics,
@@ -1502,7 +1491,7 @@ int main(int argc, char *argv[])
 	 */
 
 	overlap = options->window->data->length - options->window_shift;
-	XLALPrintInfo("%s: time series overlap is %zu samples (%.9lf s)\n", argv[0], overlap, overlap / (double) options->resample_rate);
+	XLALPrintInfo("%s: time series overlap is %i samples (%.9lf s)\n", argv[0], overlap, overlap / (double) options->resample_rate);
 
 	boundepoch = options->gps_end;
 	XLALGPSAdd(&boundepoch, -(2 * options->filter_corruption + (int) overlap) / (double) options->resample_rate);
@@ -1513,7 +1502,7 @@ int main(int argc, char *argv[])
 	 */
 
 	if(options->injection_filename) {
-		injection_document = load_injection_document(options->injection_filename, options->gps_start, options->gps_end);
+		injection_document = load_injection_document(options->injection_filename);
 		if(!injection_document) {
 			XLALPrintError("%s: error: failure reading injections file \"%s\"\n", argv[0], options->injection_filename);
 			exit(1);
@@ -1679,7 +1668,7 @@ int main(int argc, char *argv[])
 	 * Sort the events, and assign IDs.
 	 */
 
-	XLALSortSnglBurst(&_sngl_burst_table, XLALCompareSnglBurstByStartTimeAndLowFreq);
+	XLALSortSnglBurst(&_sngl_burst_table, XLALCompareSnglBurstByPeakTimeAndSNR);
 	XLALSnglBurstAssignIDs(_sngl_burst_table, _process_table->process_id, 0);
 
 	/*
@@ -1713,7 +1702,7 @@ int main(int argc, char *argv[])
 	destroy_injection_document(injection_document);
 
 	if(options->diagnostics)
-		XLALCloseLIGOLwXMLFile(options->diagnostics->LIGOLwXMLStream);
+		XLALCloseLIGOLwXMLFile(options->diagnostics);
 	options_free(options);
 
 	LALCheckMemoryLeaks();
