@@ -66,7 +66,7 @@ void get_pulsar_model( LALInferenceModel *model ){
   else if ( LALInferenceCheckVariable( model->ifo->params, "nonGR" ) ){
     /* speed of GWs as (1 - fraction of speed of light LAL_C_SI) */
     pars.cgw = rescale_parameter( model, model->ifo, "CGW" );
- 
+
     /* amplitudes for use with non-GR searches */
     /* tensor modes */
     pars.hPlus = rescale_parameter( model, model->ifo, "HPLUS" );
@@ -84,7 +84,7 @@ void get_pulsar_model( LALInferenceModel *model ){
     pars.psiVector = rescale_parameter( model, model->ifo, "PSIVECTOR" );
     pars.phi0Tensor = rescale_parameter( model, model->ifo, "PHI0TENSOR" );
     pars.psiTensor = rescale_parameter( model, model->ifo, "PSITENSOR" );
-    
+
     /* parameters that might be needed for particular models */
     pars.h0 = rescale_parameter( model, model->ifo, "H0" );
     pars.iota = rescale_parameter( model, model->ifo, "IOTA" );
@@ -93,7 +93,7 @@ void get_pulsar_model( LALInferenceModel *model ){
     if ( LALInferenceCheckVariable( model->ifo->params, "nonGRmodel" ) ){
       char* nonGRmodel;
       nonGRmodel = *(char**)LALInferenceGetVariable( model->ifo->params, "nonGRmodel" );
-      set_nonGR_model_parameters( &pars, nonGRmodel ); 
+      set_nonGR_model_parameters( &pars, nonGRmodel );
     }
   }
   else{
@@ -134,9 +134,9 @@ void get_pulsar_model( LALInferenceModel *model ){
   pars.f5 = rescale_parameter( model, model->ifo, "F5" );
 
   /* check if there are binary parameters */
-  if( LALInferenceCheckVariable(model->params, "model") ){
+  if( LALInferenceCheckVariable(model->ifo->params, "model") ){
     /* binary system model - NOT pulsar model */
-    pars.model = *(CHAR**)LALInferenceGetVariable( model->params, "model" );
+    pars.model = *(CHAR**)LALInferenceGetVariable( model->ifo->params, "model" );
 
     pars.e = rescale_parameter( model, model->ifo, "ECC" );
     pars.w0 = rescale_parameter( model, model->ifo, "OM" );
@@ -476,6 +476,15 @@ REAL8Vector *get_ssb_delay( BinaryPulsarParams pars, LIGOTimeGPSVector *datatime
 
   T0 = pars.pepoch;
 
+  /* make sure ra and dec are wrapped withing 0--2pi and -pi.2--pi/2 respectively */
+  pars.ra = fmod(pars.ra, LAL_TWOPI);
+  REAL8 absdec = fabs(pars.dec);
+  if ( absdec > LAL_PI_2 ){
+    UINT4 nwrap = floor((absdec+LAL_PI_2)/LAL_PI);
+    pars.dec = (pars.dec > 0 ? 1. : -1.)*(nwrap%2 == 1 ? -1. : 1.)*(fmod(absdec + LAL_PI_2, LAL_PI) - LAL_PI_2);
+    pars.ra = fmod(pars.ra + (REAL8)nwrap*LAL_PI, LAL_TWOPI); /* move RA by pi */
+  }
+
   #pragma omp parallel for shared(baryfail) private(bary)
   for( i=0; i<length; i++){
     if ( !baryfail ){ /* need this to quickly exit loop while using openmp (as can't use break statements) */
@@ -1198,6 +1207,10 @@ void response_lookup_table( REAL8 t0, LALDetAndSource detNSource, INT4 timeSteps
 
   INT4 j = 0, k = 0, nav = 0;
 
+  /* number of points to average */
+  if ( avedt == 60. ) { nav = 1; }
+  else{ nav = floor(avedt/60.) + 1; }
+
   /* set the polarisation angle to zero to get the a(t) and b(t) antenna pattern functions */
   detNSource.pSource->orientation = 0.0;
 
@@ -1209,9 +1222,6 @@ void response_lookup_table( REAL8 t0, LALDetAndSource detNSource, INT4 timeSteps
     aS->data[j] = 0.;
     bS->data[j] = 0.;
 
-    /* number of points to average */
-    nav = floor(avedt/60.) + 1;
-
     /* central time of lookup table point */
     T = t0 + (REAL8)j*LAL_DAYSID_SI / tsteps;
 
