@@ -93,8 +93,6 @@ typedef struct
 
   COMPLEX8FrequencySeries *transfer;  /**< detector's transfer function for use in hardware-injection */
 
-  INT4 randSeed;		/**< random-number seed: either taken from user or /dev/urandom */
-
   transientWindow_t transientWindow;	/**< properties of transient-signal window */
   CHAR *VCSInfoString;          /**< LAL + LALapps Git version string */
 } ConfigVars_t;
@@ -360,14 +358,15 @@ main(int argc, char *argv[])
 
       /* add Gaussian noise if requested */
       if ( GV.noiseSigma > 0) {
-	XLAL_CHECK ( XLALAddGaussianNoise ( Tseries, GV.noiseSigma, GV.randSeed + i_chunk ) == XLAL_SUCCESS, XLAL_EFUNC );
+        // NOTE: seed=0 means randomize seed from /dev/urandom, otherwise we'll have to increment it for each chunk here
+	XLAL_CHECK ( XLALAddGaussianNoise ( Tseries, GV.noiseSigma, (uvar.randSeed == 0) ? 0 : (uvar.randSeed + i_chunk) ) == XLAL_SUCCESS, XLAL_EFUNC );
       }
 
       /* output ASCII time-series if requested */
       if ( uvar.TDDfile )
 	{
 	  CHAR *fname = XLALCalloc (1, len = strlen(uvar.TDDfile) + 10 );
-          XLAL_CHECK ( fname != NULL, XLAL_ENOMEM, "XLALCalloc(1,%lu) failed\n", len );
+          XLAL_CHECK ( fname != NULL, XLAL_ENOMEM, "XLALCalloc(1,%zu) failed\n", len );
 	  sprintf (fname, "%s.%02d", uvar.TDDfile, i_chunk);
 	  XLAL_CHECK ( XLALdumpREAL4TimeSeries ( fname, Tseries ) == XLAL_SUCCESS, XLAL_EFUNC );
 	  XLALFree (fname);
@@ -387,7 +386,7 @@ main(int argc, char *argv[])
           XLAL_CHECK ( (fname = LALCalloc (1, len )) != NULL, XLAL_ENOMEM );
           size_t written = snprintf ( fname, len, "%s/%c-%c%c_%s-%d-%d.gwf",
                                       uvar.TDDframedir, IFO[0], IFO[0], IFO[1], uvar.frameDesc, params.startTimeGPS.gpsSeconds, (int)params.duration );
-          XLAL_CHECK ( written < len, XLAL_ESIZE, "Frame-filename exceeds expected maximal length (%lu): '%s'\n", len, fname );
+          XLAL_CHECK ( written < len, XLAL_ESIZE, "Frame-filename exceeds expected maximal length (%zu): '%s'\n", len, fname );
 
 	  /* define the output frame */
 	  LALFrameH *outFrame;
@@ -491,7 +490,7 @@ main(int argc, char *argv[])
 	  if ( uvar.outSFTv1 ) 		/* write output-SFTs using the SFT-v1 format */
 	    {
 	      CHAR *fname = XLALCalloc (1, len = strlen (uvar.outSFTbname) + 10 );
-              XLAL_CHECK ( fname != NULL, XLAL_ENOMEM, "XLALCalloc(1,%lu) failed.\n", len );
+              XLAL_CHECK ( fname != NULL, XLAL_ENOMEM, "XLALCalloc(1,%zu) failed.\n", len );
 
               LALStatus status = blank_status;
 	      for (UINT4 i=0; i < SFTs->length; i++)
@@ -510,7 +509,7 @@ main(int argc, char *argv[])
               CHAR *logstr;
               XLAL_CHECK ( (logstr = XLALUserVarGetLog ( UVAR_LOGFMT_CMDLINE )) != NULL, XLAL_EFUNC );
               char *comment = XLALCalloc ( 1, len = strlen ( logstr ) + strlen(GV.VCSInfoString) + 512 );
-              XLAL_CHECK ( comment != NULL, XLAL_ENOMEM, "XLALCalloc(1,%lu) failed.\n", len );
+              XLAL_CHECK ( comment != NULL, XLAL_ENOMEM, "XLALCalloc(1,%zu) failed.\n", len );
               sprintf ( comment, "Generated by:\n%s\n%s\n", logstr, GV.VCSInfoString );
 
               /* if user requesting single concatenated SFT */
@@ -1044,13 +1043,7 @@ XLALInitMakefakedata ( ConfigVars_t *cfg, UserVariables_t *uvar )
         }
       else if ( !strcmp ( uvar->window, "tukey" ) )
 	{
-	  if ( !XLALUserVarWasSet( &uvar->tukeyBeta ) )
-	    {
-	      uvar->tukeyBeta = 0.5;   /* If Tukey window specified, default transition fraction is 1/2 */
-	    }
-	  else if ( uvar->tukeyBeta < 0.0 || uvar->tukeyBeta > 1.0 ) {
-            XLAL_ERROR ( XLAL_EINVAL, "Tukey beta value '%f' was specified; must be between 0 and 1.\n\n", uvar->tukeyBeta );
-          }
+	  XLAL_CHECK ( (uvar->tukeyBeta >= 0.0) && (uvar->tukeyBeta <= 1.0), XLAL_EINVAL, "Tukey beta value '%f' must be between 0 and 1.\n\n", uvar->tukeyBeta );
           cfg->window = XLALCreateTukeyREAL4Window( lengthOfTimeSeries, uvar->tukeyBeta );
           XLAL_CHECK ( cfg->window != NULL, XLAL_EFUNC, "XLALCreateTukeyREAL4Window(%d, %g) failed\n", lengthOfTimeSeries, uvar->tukeyBeta );
 	}
@@ -1146,34 +1139,6 @@ XLALInitMakefakedata ( ConfigVars_t *cfg, UserVariables_t *uvar )
     else
       cfg->noiseSigma = 0;
 
-    /* set random-number generator seed: either taken from user or from /dev/urandom */
-    if ( XLALUserVarWasSet ( &uvar->randSeed ) )
-      {
-        if ( uvar->randSeed == 0 ) {
-          XLALPrintError ("WARNING: setting randSeed==0 results in the system clock being used as a random seed!\n");
-        }
-        cfg->randSeed = uvar->randSeed;
-      }
-    else
-      {
-	/*
-	 * Modified so as to not create random number parameters with seed
-	 * drawn from clock.  Seconds don't change fast enough and sft's
-	 * look alike.  We open /dev/urandom and read a 4 byte integer from
-	 * it and use that as our seed.  Note: /dev/random is slow after the
-	 * first, few accesses.
-	 */
-	FILE *devrandom = fopen ( "/dev/urandom", "r" );
-        XLAL_CHECK ( devrandom != NULL, XLAL_EIO, "fopen() failed to open '/dev/urandom' for reading\n\n");
-
-	if ( fread( (void*)&(cfg->randSeed), sizeof(INT4), 1, devrandom) != 1 )
-	  {
-	    fclose ( devrandom );
-	    XLAL_ERROR ( XLAL_EIO, "Failed to read from '/dev/urandom'\n\n");
-	  }
-	fclose ( devrandom );
-      }
-
   } /* END: Noise params */
 
 
@@ -1339,7 +1304,7 @@ XLALInitUserVars ( UserVariables_t *uvar, int argc, char *argv[] )
   XLALregREALUserStruct (  actuationScale,       0,  UVAR_DEVELOPER,  "(Signed) scale-factor to apply to the actuation-function.");
 
   XLALregBOOLUserStruct (  exactSignal,          0, UVAR_DEVELOPER, "Generate signal time-series as exactly as possible (slow).");
-  XLALregINTUserStruct (   randSeed,             0, UVAR_DEVELOPER, "Specify random-number seed for reproducible noise (use /dev/urandom otherwise).");
+  XLALregINTUserStruct (   randSeed,             0, UVAR_DEVELOPER, "Specify random-number seed for reproducible noise (0 means use /dev/urandom for seeding).");
   XLALregBOOLUserStruct ( outSFTv1,	 	 0, UVAR_DEVELOPER,   "[deprecated] Write output-SFTs in obsolete SFT-v1 format." );
 
   // ----- deprecated but still supported options [throw warning if used] ----------
@@ -1352,9 +1317,9 @@ XLALInitUserVars ( UserVariables_t *uvar, int argc, char *argv[] )
   XLALRegisterUvarMember ( Dec,		STRING,  0, DEPRECATED, "Use --Delta instead");
 
   // ----- deprecated and unsupported options [throw error if used] ----------
-  XLALRegisterUvarMember ( orbitTpSSBsec, INT4,  0, OBSOLETE, "Use --orbitTp instead");
-  XLALRegisterUvarMember ( orbitTpSSBnan, INT4,  0, OBSOLETE, "Use --orbitTp instead");
-  XLALRegisterUvarMember ( orbitTpSSBMJD, STRING,0, OBSOLETE, "Use --orbitTp instead");
+  XLALRegisterUvarMember ( orbitTpSSBsec, INT4,  0, DEFUNCT, "Obsolete, use --orbitTp instead");
+  XLALRegisterUvarMember ( orbitTpSSBnan, INT4,  0, DEFUNCT, "Obsolete, use --orbitTp instead");
+  XLALRegisterUvarMember ( orbitTpSSBMJD, STRING,0, DEFUNCT, "Obsolete, use --orbitTp instead");
 
   /* read cmdline & cfgfile  */
   ret = XLALUserVarReadAllInput ( argc, argv );
