@@ -84,6 +84,7 @@ typedef struct
   INT4 Tsft;			/**< assumed length of SFTs, needed for offset to timestamps when comparing to CFS_v2, PFS etc */
 
   LALStringVector* noiseSqrtShX; /**< per-detector noise PSD sqrt(SX) */
+  BOOLEAN singleIFOweighting;	/**< Normalize single-IFO quantities by single-IFO SX instead of Stot */
 
   CHAR *outab; 			/**< output file for antenna pattern functions a(t), b(t) at each timestamp */
   CHAR *outABCD; 		/**< output file for antenna pattern matrix elements A, B, C, D averaged over timestamps */
@@ -153,7 +154,9 @@ main(int argc, char *argv[])
       }
       else {
         for ( UINT4 X=0; X < config.numDetectors; X++ ) {
-          fprintf(fpOutab, "      a[%d](t)      b[%d](t)", X, X);
+          char* detectorID;
+          detectorID = config.multiDetStates->data[X]->detector.frDetector.prefix;
+          fprintf(fpOutab, "      a_%s(t)      b_%s(t)", detectorID, detectorID);
         }
       }
       fprintf(fpOutab, "\n");
@@ -176,11 +179,20 @@ main(int argc, char *argv[])
 
       /* write column headings */
       fprintf(fpOutABCD, "%%%% columns:\n%%%% Alpha   Delta");
-      fprintf(fpOutABCD, "        A            B            C            D");
+      if ( config.numDetectors == 1 ) {
+        char* detectorID;
+        detectorID = config.multiDetStates->data[0]->detector.frDetector.prefix;
+        fprintf(fpOutABCD, "        A_%s         B_%s         C_%s         D_%s", detectorID, detectorID, detectorID, detectorID);
+      }
+      else {
+        fprintf(fpOutABCD, "        A            B            C            D");
+      }
       if ( config.numDetectors > 1 ) {
         fprintf(fpOutABCD, "   ");
         for ( UINT4 X=0; X < config.numDetectors; X++ ) {
-          fprintf(fpOutABCD, "         A[%d]         B[%d]         C[%d]         D[%d]", X, X, X, X);
+          char* detectorID;
+          detectorID = config.multiDetStates->data[X]->detector.frDetector.prefix;
+          fprintf(fpOutABCD, "         A_%s         B_%s         C_%s         D_%s", detectorID, detectorID, detectorID, detectorID);
         }
       }
       fprintf(fpOutABCD, "\n");
@@ -203,7 +215,7 @@ main(int argc, char *argv[])
      */
     MultiAMCoeffs *multiAMforSingle = NULL;
     MultiAMCoeffs *multiAMunweighted = NULL;
-    if ( ( config.numDetectors > 1 ) && ( config.multiNoiseWeights != NULL ) ) {
+    if ( uvar.singleIFOweighting && ( config.numDetectors > 1 ) && ( config.multiNoiseWeights != NULL ) ) {
       XLAL_CHECK ( ( multiAMunweighted = XLALComputeMultiAMCoeffs ( config.multiDetStates, NULL, skypos ) ) != NULL, XLAL_EFUNC, "XLALComputeAMCoeffs() failed." );
       multiAMforSingle = multiAMunweighted;
     }
@@ -289,6 +301,7 @@ XLALInitUserVars ( UserVariables_t *uvar )
   uvar->timeStampsFile = NULL;
   uvar->outab = 0;
   uvar->outABCD = 0;
+  uvar->singleIFOweighting = 0;
   uvar->Tsft = 1800;
 
   uvar->noiseSqrtShX = NULL;
@@ -307,6 +320,7 @@ XLALInitUserVars ( UserVariables_t *uvar )
   XLALregINTUserStruct(		Tsft,		 0, UVAR_OPTIONAL,	"Assumed length of one SFT in seconds; needed for timestamps offset consistency with F-stat based codes");
 
   XLALregLISTUserStruct ( noiseSqrtShX,		 0, UVAR_OPTIONAL, "Per-detector noise PSD sqrt(SX). Only ratios relevant to compute noise weights. Defaults to 1,1,...");
+  XLALregBOOLUserStruct ( singleIFOweighting,	 0, UVAR_OPTIONAL, "Normalize single-IFO quantities by single-IFO SX instead of Stot");
 
   XLALregSTRINGUserStruct (	ephemEarth,	 0,  UVAR_OPTIONAL,	"Earth ephemeris file to use");
   XLALregSTRINGUserStruct (	ephemSun,	 0,  UVAR_OPTIONAL,	"Sun ephemeris file to use");
@@ -483,11 +497,11 @@ XLALInitCode ( ConfigVariables *cfg, const UserVariables_t *uvar, const char *ap
 
     /* create multi noise weights */
     if ( (cfg->multiNoiseWeights = XLALCalloc(1, sizeof(*cfg->multiNoiseWeights))) == NULL ) {
-     XLALPrintError ("%s: failed to XLALCalloc ( 1, %lu )\n", __func__, sizeof(*cfg->multiNoiseWeights) );
+     XLALPrintError ("%s: failed to XLALCalloc ( 1, %zu )\n", __func__, sizeof(*cfg->multiNoiseWeights) );
      XLAL_ERROR ( XLAL_ENOMEM );
     }
     if ( (cfg->multiNoiseWeights->data = XLALCalloc(cfg->numDetectors, sizeof(*cfg->multiNoiseWeights->data))) == NULL ) {
-     XLALPrintError ("%s: failed to XLALCalloc ( %d, %lu )\n", __func__, cfg->numDetectors, sizeof(*cfg->multiNoiseWeights->data) );
+     XLALPrintError ("%s: failed to XLALCalloc ( %d, %zu )\n", __func__, cfg->numDetectors, sizeof(*cfg->multiNoiseWeights->data) );
      XLAL_ERROR ( XLAL_ENOMEM );
     }
     cfg->multiNoiseWeights->length = cfg->numDetectors;
