@@ -19,29 +19,44 @@
 
 #include <math.h>
 #include <lal/SSBtimes.h>
+#include <lal/DetResponse.h>
+#include <lal/Velocity.h>
 #include "antenna.h"
 
 /**
  * \brief Compute the number of integer bin shifts per SFT
  *
- * bin shift = f0*v*Tcoh, where f0 is frequency, v is velocity in units of c, and Tcoh is the SFT coherence length.
+ * bin shift = f0*v*Tsft, where f0 is frequency, v is velocity in units of c, and Tsft is the SFT coherence length.
  * An optional dopplerMultiplier value could be multiplied if desired (default value is 1.0)
  * \param [out] output            Pointer to INT4Vector of bin shift values
  * \param [in]  freq              Frequency from which to compute the bin shifts
  * \param [in]  velocities        Pointer to REAL4Vector of detector velocities with respect to a sky location
- * \param [in]  Tcoh              Coherence length of the SFTs
+ * \param [in]  Tsft              Coherence length of the SFTs
  * \param [in]  dopplerMultiplier Multiplicative factor to increase or decrease the bin shifts (standard physics = 1.0)
  * \return Status value
  */
-INT4 CompBinShifts(INT4Vector *output, REAL8 freq, REAL4Vector *velocities, REAL8 Tcoh, REAL4 dopplerMultiplier)
+INT4 CompBinShifts(INT4Vector *output, REAL8 freq, REAL4Vector *velocities, REAL8 Tsft, REAL4 dopplerMultiplier)
 {
    XLAL_CHECK( output != NULL && velocities != NULL, XLAL_EINVAL );
-   for (INT4 ii=0; ii<(INT4)velocities->length; ii++) output->data[ii] = (INT4)round(dopplerMultiplier*freq*velocities->data[ii]*Tcoh);
+   for (UINT4 ii=0; ii<velocities->length; ii++) output->data[ii] = (INT4)round(dopplerMultiplier*freq*velocities->data[ii]*Tsft);
    return XLAL_SUCCESS;
 } /* CompBinShifts() */
+
+/**
+ * \brief Compute the number of integer bin shifts per SFT
+ *
+ * bin shift = f0*v*Tsft, where f0 is frequency, v is velocity in units of c, and Tsft is the SFT coherence length.
+ * An optional dopplerMultiplier value could be multiplied if desired (default value is 1.0)
+ * \param [out] output            Pointer to INT4Vector of bin shift values
+ * \param [in]  ssbTimes          Pointer to the interferometer-specific SSBtimes
+ * \param [in]  freq              Frequency from which to compute the bin shifts
+ * \param [in]  Tsft              Coherence length of the SFTs
+ * \param [in]  dopplerMultiplier Multiplicative factor to increase or decrease the bin shifts (standard physics = 1.0)
+ * \return Status value
+ */
 INT4 CompBinShifts2(INT4Vector *output, SSBtimes *ssbTimes, REAL8 freq, REAL8 Tsft, REAL4 dopplerMultiplier)
 {
-   for (INT4 ii=0; ii<(INT4)output->length; ii++) output->data[ii] = (INT4)round(dopplerMultiplier*(ssbTimes->Tdot->data[ii]-1.0)*freq*Tsft);
+   for (UINT4 ii=0; ii<output->length; ii++) output->data[ii] = (INT4)round(dopplerMultiplier*(ssbTimes->Tdot->data[ii]-1.0)*freq*Tsft);
    return XLAL_SUCCESS;
 }
 
@@ -51,10 +66,9 @@ INT4 CompBinShifts2(INT4Vector *output, SSBtimes *ssbTimes, REAL8 freq, REAL8 Ts
  * If linPolOn = 0, then the output weights are Fplus*Fplus + Fcross*Fcross,
  * or if linPolOn = 1, then the output weights are Fplus*Fplus for the given polarization angle
  * \param [out] output     Pointer to REAL4Vector of antenna pattern weights
- * \param [in]  ra         Right ascension value (radians)
- * \param [in]  dec        Declination value (radians)
+ * \param [in]  skypos     Sky position measured in RA and Dec in radians
  * \param [in]  t0         Start time (GPS seconds)
- * \param [in]  Tcoh       Coherence length of the SFTs (in seconds)
+ * \param [in]  Tsft       Coherence length of the SFTs (in seconds)
  * \param [in]  SFToverlap Overlap of the SFTs (in seconds)
  * \param [in]  Tobs       Observation time (in seconds)
  * \param [in]  linPolOn   Flag for linear polarizations (linPolOn = 0 is circular polarization weights, linPolOn = 1 is linear polarization weights)
@@ -62,23 +76,23 @@ INT4 CompBinShifts2(INT4Vector *output, SSBtimes *ssbTimes, REAL8 freq, REAL8 Ts
  * \param [in]  det        A LALDetector struct
  * \return Status value
  */
-INT4 CompAntennaPatternWeights(REAL4Vector *output, REAL4 ra, REAL4 dec, REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs, INT4 linPolOn, REAL8 polAngle, LALDetector det)
+INT4 CompAntennaPatternWeights(REAL4Vector *output, SkyPosition skypos, REAL8 t0, REAL8 Tsft, REAL8 SFToverlap, REAL8 Tobs, BOOLEAN linPolOn, REAL8 polAngle, LALDetector det)
 {
 
    XLAL_CHECK( output != NULL, XLAL_EINVAL );
 
-   INT4 numffts = (INT4)floor(Tobs/(Tcoh-SFToverlap)-1);    //Number of FFTs
+   INT4 numffts = (INT4)floor(Tobs/(Tsft-SFToverlap)-1);    //Number of FFTs
    REAL8 fplus, fcross;
 
    for (INT4 ii=0; ii<numffts; ii++) {
 
       LIGOTimeGPS gpstime = LIGOTIMEGPSZERO;
-      gpstime.gpsSeconds = (INT4)floor(t0 + ii*(Tcoh-SFToverlap) + 0.5*Tcoh);
-      gpstime.gpsNanoSeconds = (INT4)floor((t0+ii*(Tcoh-SFToverlap)+0.5*Tcoh - floor(t0+ii*(Tcoh-SFToverlap)+0.5*Tcoh))*1e9);
+      gpstime.gpsSeconds = (INT4)floor(t0 + ii*(Tsft-SFToverlap) + 0.5*Tsft);
+      gpstime.gpsNanoSeconds = (INT4)floor((t0+ii*(Tsft-SFToverlap)+0.5*Tsft - floor(t0+ii*(Tsft-SFToverlap)+0.5*Tsft))*1e9);
       REAL8 gmst = XLALGreenwichMeanSiderealTime(&gpstime);
       XLAL_CHECK( xlalErrno == 0, XLAL_EFUNC );
 
-      XLALComputeDetAMResponse(&fplus, &fcross, (const REAL4(*)[3])det.response, ra, dec, polAngle, gmst);
+      XLALComputeDetAMResponse(&fplus, &fcross, (const REAL4(*)[3])det.response, skypos.longitude, skypos.latitude, polAngle, gmst);
       XLAL_CHECK( xlalErrno == 0, XLAL_EFUNC );
 
       if (!linPolOn) output->data[ii] = (REAL4)(fplus*fplus + fcross*fcross);
@@ -94,36 +108,34 @@ INT4 CompAntennaPatternWeights(REAL4Vector *output, REAL4 ra, REAL4 dec, REAL8 t
 /**
  * Compute the antenna velocity
  * \param [out] output     Pointer to REAL4Vector of antenna velocities
- * \param [in]  ra         Right ascension value (radians)
- * \param [in]  dec        Declination value (radians)
+ * \param [in]  skypos     Sky position measured in RA and Dec in radians
  * \param [in]  t0         Start time (GPS seconds)
- * \param [in]  Tcoh       Coherence length of the SFTs (in seconds)
+ * \param [in]  Tsft       Coherence length of the SFTs (in seconds)
  * \param [in]  SFToverlap Overlap of the SFTs (in seconds)
  * \param [in]  Tobs       Observation time (in seconds)
  * \param [in]  det        A LALDetector struct
  * \param [in]  edat       Pointer to EphemerisData
  * \return Status value
  */
-INT4 CompAntennaVelocity(REAL4Vector *output, REAL4 ra, REAL4 dec, REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat)
+INT4 CompAntennaVelocity(REAL4Vector *output, SkyPosition skypos, REAL8 t0, REAL8 Tsft, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat)
 {
 
    XLAL_CHECK( output != NULL && edat != NULL, XLAL_EINVAL );
 
-   INT4 ii;
-   INT4 numffts = (INT4)floor(Tobs/(Tcoh-SFToverlap)-1);    //Number of FFTs
+   INT4 numffts = (INT4)floor(Tobs/(Tsft-SFToverlap)-1);    //Number of FFTs
    LALStatus XLAL_INIT_DECL(status);
 
    REAL8 detvel[3];
-   for (ii=0; ii<numffts; ii++) {
+   for (INT4 ii=0; ii<numffts; ii++) {
 
       LIGOTimeGPS gpstime = LIGOTIMEGPSZERO;
-      gpstime.gpsSeconds = (INT4)floor(t0 + ii*(Tcoh-SFToverlap) + 0.5*Tcoh);
-      gpstime.gpsNanoSeconds = (INT4)floor((t0+ii*(Tcoh-SFToverlap)+0.5*Tcoh - floor(t0+ii*(Tcoh-SFToverlap)+0.5*Tcoh))*1e9);
+      gpstime.gpsSeconds = (INT4)floor(t0 + ii*(Tsft-SFToverlap) + 0.5*Tsft);
+      gpstime.gpsNanoSeconds = (INT4)floor((t0+ii*(Tsft-SFToverlap)+0.5*Tsft - floor(t0+ii*(Tsft-SFToverlap)+0.5*Tsft))*1e9);
 
       LALDetectorVel(&status, detvel, &gpstime, det, edat);
       XLAL_CHECK( status.statusCode == 0, XLAL_EFUNC );
 
-      output->data[ii] = (REAL4)(detvel[0]*cos(ra)*cos(dec) + detvel[1]*sin(ra)*cos(dec) + detvel[2]*sin(dec));
+      output->data[ii] = (REAL4)(detvel[0]*cos(skypos.longitude)*cos(skypos.latitude) + detvel[1]*sin(skypos.longitude)*cos(skypos.latitude) + detvel[2]*sin(skypos.latitude));
 
    } /* for ii < numffts */
 
@@ -135,30 +147,27 @@ INT4 CompAntennaVelocity(REAL4Vector *output, REAL4 ra, REAL4 dec, REAL8 t0, REA
 /**
  * Compute the maximum change in antenna velocity
  * \param [in]  t0         Start time (GPS seconds)
- * \param [in]  Tcoh       Coherence length of the SFTs (in seconds)
+ * \param [in]  Tsft       Coherence length of the SFTs (in seconds)
  * \param [in]  SFToverlap Overlap of the SFTs (in seconds)
  * \param [in]  Tobs       Observation time (in seconds)
  * \param [in]  det        A LALDetector struct
  * \param [in]  edat       Pointer to EphemerisData
  * \return Maximum change in antenna velocity
  */
-REAL4 CompDetectorDeltaVmax(REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat)
+REAL4 CompDetectorDeltaVmax(REAL8 t0, REAL8 Tsft, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat)
 {
 
    XLAL_CHECK( edat != NULL, XLAL_EINVAL );
 
-   INT4 ii;
-   INT4 numffts = (INT4)floor(Tobs/(Tcoh-SFToverlap)-1);    //Number of FFTs
+   INT4 numffts = (INT4)floor(Tobs/(Tsft-SFToverlap)-1);    //Number of FFTs
    LALStatus XLAL_INIT_DECL(status);
 
-   REAL8 detvel[3];
-   REAL8 detvel0[3];
-   REAL8 dv[3];
+   REAL8 detvel[3], detvel0[3], dv[3];
    REAL4 deltaVmax = 0.0;
-   for (ii=0; ii<numffts; ii++) {
+   for (INT4 ii=0; ii<numffts; ii++) {
       LIGOTimeGPS gpstime = LIGOTIMEGPSZERO;
-      gpstime.gpsSeconds = (INT4)floor(t0 + ii*(Tcoh-SFToverlap) + 0.5*Tcoh);
-      gpstime.gpsNanoSeconds = (INT4)floor((t0+ii*(Tcoh-SFToverlap)+0.5*Tcoh - floor(t0+ii*(Tcoh-SFToverlap)+0.5*Tcoh))*1e9);
+      gpstime.gpsSeconds = (INT4)floor(t0 + ii*(Tsft-SFToverlap) + 0.5*Tsft);
+      gpstime.gpsNanoSeconds = (INT4)floor((t0+ii*(Tsft-SFToverlap)+0.5*Tsft - floor(t0+ii*(Tsft-SFToverlap)+0.5*Tsft))*1e9);
 
       if (ii==0) {
          LALDetectorVel(&status, detvel0, &gpstime, det, edat);
@@ -183,39 +192,38 @@ REAL4 CompDetectorDeltaVmax(REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs,
 /**
  * Compute the largest magnitude of antenna velocity
  * \param [in]  t0         Start time (GPS seconds)
- * \param [in]  Tcoh       Coherence length of the SFTs (in seconds)
+ * \param [in]  Tsft       Coherence length of the SFTs (in seconds)
  * \param [in]  SFToverlap Overlap of the SFTs (in seconds)
  * \param [in]  Tobs       Observation time (in seconds)
  * \param [in]  det        A LALDetector struct
  * \param [in]  edat       Pointer to EphemerisData
  * \return Maximum magnitude of antenna velocity
  */
-REAL4 CompDetectorVmax(REAL8 t0, REAL8 Tcoh, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat)
+REAL4 CompDetectorVmax(REAL8 t0, REAL8 Tsft, REAL8 SFToverlap, REAL8 Tobs, LALDetector det, EphemerisData *edat)
 {
 
    XLAL_CHECK( edat != NULL, XLAL_EINVAL );
 
-   INT4 ii;
-   INT4 numffts = (INT4)floor(Tobs/(Tcoh-SFToverlap)-1);    //Number of FFTs
+   INT4 numffts = (INT4)floor(Tobs/(Tsft-SFToverlap)-1);    //Number of FFTs
    LALStatus XLAL_INIT_DECL(status);
 
-   REAL8 detvel[3];
-   REAL4 Vmax = 0.0;
-   for (ii=0; ii<numffts; ii++) {
-      LIGOTimeGPS gpstime = LIGOTIMEGPSZERO;
-      gpstime.gpsSeconds = (INT4)floor(t0 + ii*(Tcoh-SFToverlap) + 0.5*Tcoh);
-      gpstime.gpsNanoSeconds = (INT4)floor((t0+ii*(Tcoh-SFToverlap)+0.5*Tcoh - floor(t0+ii*(Tcoh-SFToverlap)+0.5*Tcoh))*1e9);
+   LIGOTimeGPS gpstime = LIGOTIMEGPSZERO;
+   gpstime.gpsSeconds = (INT4)floor(t0 + 0.5*Tsft);
+   gpstime.gpsNanoSeconds = (INT4)floor((t0+0.5*Tsft - floor(t0+0.5*Tsft))*1e9);
 
-      if (ii==0) {
-         LALDetectorVel(&status, detvel, &gpstime, det, edat);
-         XLAL_CHECK_REAL4( status.statusCode == 0, XLAL_EFUNC );
-         Vmax = (REAL4)sqrt(detvel[0]*detvel[0] + detvel[1]*detvel[1] + detvel[2]*detvel[2]);
-      } else {
-         LALDetectorVel(&status, detvel, &gpstime, det, edat);
-         XLAL_CHECK_REAL4( status.statusCode == 0, XLAL_EFUNC );
-         REAL4 V = (REAL4)sqrt(detvel[0]*detvel[0] + detvel[1]*detvel[1] + detvel[2]*detvel[2]);
-         if (V > Vmax) Vmax = V;
-      } /* if ii==0 else ... */
+   REAL8 detvel[3];
+   LALDetectorVel(&status, detvel, &gpstime, det, edat);
+   XLAL_CHECK_REAL4( status.statusCode == 0, XLAL_EFUNC );
+   REAL4 Vmax = (REAL4)sqrt(detvel[0]*detvel[0] + detvel[1]*detvel[1] + detvel[2]*detvel[2]);
+
+   for (INT4 ii=1; ii<numffts; ii++) {
+      gpstime.gpsSeconds = (INT4)floor(t0 + ii*(Tsft-SFToverlap) + 0.5*Tsft);
+      gpstime.gpsNanoSeconds = (INT4)floor((t0+ii*(Tsft-SFToverlap)+0.5*Tsft - floor(t0+ii*(Tsft-SFToverlap)+0.5*Tsft))*1e9);
+
+      LALDetectorVel(&status, detvel, &gpstime, det, edat);
+      XLAL_CHECK_REAL4( status.statusCode == 0, XLAL_EFUNC );
+      REAL4 V = (REAL4)sqrt(detvel[0]*detvel[0] + detvel[1]*detvel[1] + detvel[2]*detvel[2]);
+      if (V > Vmax) Vmax = V;
    } /* for ii < numffts */
 
    return Vmax;
