@@ -36,7 +36,7 @@ void free_UpperLimitVector(UpperLimitVector *vector);
 void free_UpperLimitStruct(UpperLimit *ul);
 
 
-INT4 skypoint95UL(UpperLimit *ul, inputParamsStruct *params, ffdataStruct *ffdata, ihsMaximaStruct *ihsmaxima, ihsfarStruct *ihsfar, REAL4Vector *fbinavgs);
+INT4 skypoint95UL(UpperLimit *ul, UserInput_t *params, ffdataStruct *ffdata, ihsMaximaStruct *ihsmaxima, ihsfarStruct *ihsfar, REAL4Vector *fbinavgs);
 REAL8 gsl_ncx2cdf_solver(REAL8 x, void *p);
 REAL8 gsl_ncx2cdf_float_solver(REAL8 x, void *p);
 REAL8 gsl_ncx2cdf_withouttinyprob_solver(REAL8 x, void *p);
