@@ -17,9 +17,12 @@
 *  MA  02111-1307  USA
 */
 
+#include <config.h>
 
 #include <stdio.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include "CrossCorrToplist.h"
 #include "HeapToplist.h"
 #include <lal/StringInput.h> /* for LAL_REAL8_FORMAT etc. */
@@ -248,7 +251,7 @@ void sort_crossCorrBinary_toplist(toplist_t*l) {
 /* 	return -2; */
 
 /*     /\* make sure the line buffer is terminated correctly *\/ */
-/*     line[sizeof(line)-1]='\0'; */
+/*     XLAL_LAST_ELEM(line)='\0'; */
 
 /*     /\* init the checksum if given *\/ */
 /*     if(checksum) */
@@ -382,7 +385,7 @@ void sort_crossCorrBinary_toplist(toplist_t*l) {
 /* 	return -2; */
 
 /*     /\* make sure the line buffer is terminated correctly *\/ */
-/*     line[sizeof(line)-1]='\0'; */
+/*     XLAL_LAST_ELEM(line)='\0'; */
 
 /*     /\* init the checksum if given *\/ */
 /*     if(checksum) */
@@ -544,7 +547,7 @@ int write_crossCorr_toplist_item_to_fp(CrossCorrOutputEntry fline, FILE*fp, UINT
 	for(i=0;i<length;i++)
 	    *checksum += linebuf[i];
 
-    linebuf[sizeof(linebuf)-1] = '\0';
+    XLAL_LAST_ELEM(linebuf) = '\0';
 
     return(fprintf(fp,"%s",linebuf));
 }
@@ -564,7 +567,7 @@ int write_crossCorrBinary_toplist_item_to_fp(CrossCorrBinaryOutputEntry fline, F
 	for(i=0;i<length;i++)
 	    *checksum += linebuf[i];
 
-    linebuf[sizeof(linebuf)-1] = '\0';
+    XLAL_LAST_ELEM(linebuf) = '\0';
 
     return(fprintf(fp,"%s",linebuf));
 }
@@ -897,7 +900,7 @@ int write_cc_checkpoint(const char*filename, toplist_t*tl, UINT4 counter, BOOLEA
   len = fwrite(tl->data, tl->size, tl->elems, fp);
   if(len != tl->elems) {
     LOGIOERROR("Couldn't write data to", tmpfilename);
-    LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %d\n", len, tl->elems);
+    LogPrintf(LOG_CRITICAL,"fwrite() returned %d, length was %zu\n", len, tl->elems);
     if(fclose(fp))
       LOGIOERROR("In addition: couldn't close", tmpfilename);
     return(-1);
@@ -986,7 +989,7 @@ int read_cc_checkpoint(const char*filename, toplist_t*tl, UINT4*counter) {
   /* sanity check */
   if (tl->elems > tl->length) {
     LogPrintf(LOG_CRITICAL,
-	      "Number of elements read larger than length of toplist: %d, > %d\n",
+	      "Number of elements read larger than length of toplist: %zu > %zu\n",
 	      tl->elems, tl->length);
     if(fclose(fp))
       LOGIOERROR("In addition: couldn't close", filename);
@@ -997,7 +1000,7 @@ int read_cc_checkpoint(const char*filename, toplist_t*tl, UINT4*counter) {
   len = fread(tl->data, tl->size, tl->elems, fp);
   if(len != tl->elems) {
     LOGIOERROR("Couldn't read data from", filename);
-    LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %d\n", len, tl->elems);
+    LogPrintf(LOG_CRITICAL,"fread() returned %d, length was %zu\n", len, tl->elems);
     if(fclose(fp))
       LOGIOERROR("In addition: couldn't close", filename);
     clear_toplist(tl);
