@@ -20,6 +20,7 @@
 /**
  * \author Gregory Mendell
  * \file StackSlideFstat.c
+ * \ingroup lalapps_pulsar_hough
  * \brief Module with functions that StackSlide a vector of Fstat values or any REAL8FrequencySeriesVector.
  */
 
@@ -521,7 +522,7 @@ void StackSlideVecF_HoughMode(LALStatus *status,		/**< pointer to LALStatus stru
   fBinFin -= params->extraBinsFstat;
   /* this is not very clean -- the Fstat calculation has to know how many extra bins are needed */
 
-  LogPrintf(LOG_DETAIL, "Freq. range analyzed by Hough = [%fHz - %fHz] (%d bins)\n", 
+  LogPrintf(LOG_DETAIL, "Freq. range analyzed by Hough = [%fHz - %fHz] (%"LAL_INT8_FORMAT" bins)\n",
 	    fBinIni*deltaF, fBinFin*deltaF, fBinFin - fBinIni + 1);
   ASSERT ( fBinIni < fBinFin, status, HIERARCHICALSEARCH_EVAL, HIERARCHICALSEARCH_MSGEVAL );
 
